@@ -147,7 +147,7 @@ class OrderedAndRecieved(BASE,Template):
     #dmv error processing unit
     #let them know that i filled out my application on sept. 9.
     How_are_wages_being_dispensed=Column(String,default=None)
-    
+
     RateOfPay=Column(Float,default=None)
     RateOfPayComment=Column(Float,default=None)
     RateOfPayBy=Column(String,default=None)
@@ -158,15 +158,15 @@ class OrderedAndRecieved(BASE,Template):
 
     Paid_When_DT=Column(DateTime,default=None)
     Shift_Started_DT=Column(DateTime,default=None)
-    Shift_Lunch_Start=Column(DateTime,default=False)
-    Shift_Lunch_End=Column(DateTime,default=False)
+    Shift_Lunch_Start=Column(DateTime,default=None)
+    Shift_Lunch_End=Column(DateTime,default=None)
     Shift_Ended_DT=Column(DateTime,default=None)
     Shift_Labor_Breaks=Column(Text,default=None)
-    is_lunch_paid=Column(Boolean,default=False)
-    is_break_paid=Column(Boolean,default=False)
+    is_lunch_paid=Column(Boolean,default=None)
+    is_break_paid=Column(Boolean,default=None)
 
     #schedule 
-    Was_This_A_Scheduled_Shift=Column(Boolean,default=True)
+    Was_This_A_Scheduled_Shift=Column(Boolean,default=None)
     ScheduledShiftDTOE=Column(DateTime,default=None)
     ScheduledDays=Column(String,default=None)
     ScheduledShiftNotes=Column(String,default=None)
@@ -188,7 +188,7 @@ class OrderedAndRecieved(BASE,Template):
     SupervisorName=Column(String,default=None)
     SupervisorNotes=Column(Text,default=None)
 
-    PersonInChargePresent=Column(Boolean,default=True)
+    PersonInChargePresent=Column(Boolean,default=None)
     PersonInChargeName=Column(String,default=None)
     PersonInChargeNotes=Column(Text,default=None)
 
