@@ -22,6 +22,26 @@ preloader={
 						'desc':f'find the resonant inductance for LC using L = 1 / (4π²f²C)',
 						'exec':resonant_inductance
 					},
+	f'{uuid1()}':{
+						'cmds':['cost to run','c2r'],
+						'desc':f'find the cost to run a device per day',
+						'exec':costToRun
+				    },
+	f'{uuid1()}':{
+						'cmds':['now to % time','n2pt'],
+						'desc':f'now to percent time, or time to go',
+						'exec':ndtp
+				    },
+	f'{uuid1()}':{
+						'cmds':['generic item or service text template','txt gios '],
+						'desc':f'find the cost to run a device per day',
+						'exec':generic_service_or_item
+				    },
+		f'{uuid1()}':{
+						'cmds':['reciept book entry','rbe'],
+						'desc':f'reciept book data to name template',
+						'exec':reciept_book_entry,
+				    },
 	f'{uuid1()}':{
 						'cmds':['air coil',],
 						'desc':f''' 
