@@ -1424,4 +1424,219 @@ class candidates:
                 pzl=mkpuzl()
                 continue
             else:
-                continue
\ No newline at end of file
+                continue
+
+
+def costToRun():
+    fields={
+    'wattage of device plugged in, turned on/off?':{
+        'default':60,
+        'type':'float'
+    },
+    'hours of use?':{
+        'default':1,
+        'type':'float'
+    },
+    'electrical providers cost per kWh':{
+        'default':0.70  ,
+        'type':'float'
+    },
+    }
+
+    fd=FormBuilder(data=fields)
+    if fd is None:
+        return
+   
+    cost=((fd['wattage of device plugged in, turned on/off?']/1000)*fd['electrical providers cost per kWh'])
+    total_cost_to=cost*fd['hours of use?']
+    return total_cost_to
+
+
+def generic_service_or_item():
+    fields={
+    'PerBaseUnit':{
+        'default':'squirt',
+        'type':'string',
+        },
+    'PerBaseUnit_is_EquivalentTo[Conversion]':{
+        'default':'1 squirt == 2 grams',
+        'type':'string',
+        },
+    'PricePer_1_EquivalentTo[Conversion]':{
+        'default':0,
+        'type':'float',
+        },
+    'Name or Description':{
+        'default':'dawn power wash',
+        'type':'string'
+        },
+    'Cost/Price/Expense Taxed @ %':{
+        'default':'Item was purchased for 3.99 Taxed @ 6.3% (PRICE+(PRICE+TAX))',
+        'type':'string'
+        },
+    'Where was the item purchased/sold[Location/Street Address, City, State ZIP]?':{
+        'default':'walmart in gloucester va, 23061',
+        'type':'string'
+        },
+    }
+    fd=FormBuilder(data=fields)
+    if fd is not None:
+        textty=[]
+        cta=len(fd)
+        for num,k in enumerate(fd):
+            msg=f"{k} = '{fd[k]}'"
+            textty.append(strip_colors(std_colorize(msg,num,cta)))
+        master=f'''
+Non-Std Item/Non-Std Service
+----------------------------
+{' '+'\n '.join(textty)}
+----------------------------
+        '''
+        return master
+
+def reciept_book_entry():
+    fields={
+    'reciept number':{
+        'default':'',
+        'type':'string'
+    },
+    'reciept dtoe':{
+        'default':datetime.now(),
+        'type':'datetime'
+    },
+    'recieved from':{
+        'default':'',
+        'type':'string'
+    },
+    'address':{
+        'default':'',
+        'type':'string'
+    },
+    'Amount ($)':{
+        'default':0,
+        'type':'dec.dec',
+    },
+    'For':{
+        'default':'',
+        'type':'string'
+    },
+    'By':{
+        'default':'',
+        'type':'string'
+    },
+    'Amount of Account':{
+        'default':0,
+        'type':'dec.dec',
+    },
+    'Amount Paid':{
+        'default':0,
+        'type':'dec.dec',
+    },
+    'Balance Due':{
+        'default':0,
+        'type':'dec.dec',
+    },
+    'Cash':{
+        'default':0,
+        'type':'dec.dec',
+    },
+    'Check':{
+        'default':0,
+        'type':'dec.dec',
+    },
+    'Money Order':{
+        'default':0,
+        'type':'dec.dec',
+    },
+    'Line 1':{
+        'default':'',
+        'type':'string'
+    },
+    'Line 2':{
+        'default':'',
+        'type':'string'
+    },
+    'Notes':{
+        'default':'',
+        'type':'string'
+    },
+    'Filing Location Id':{
+        'default':'',
+        'type':'string'
+    },
+    }
+    fd=FormBuilder(data=fields)
+    if fd is not None:
+        textty=[]
+        cta=len(fd)
+        for num,k in enumerate(fd):
+            msg=f"{k} = '{fd[k]}'"
+            textty.append(strip_colors(std_colorize(msg,num,cta)))
+        master=f'''
+Reciept {fd['reciept number']}
+----------------------------
+{' '+'\n '.join(textty)}
+----------------------------
+        '''
+        return master
+
+def nowToPercentTime(now=None):
+    if not isinstance(now,datetime):
+        now=datetime.now()
+    today=datetime(now.year,now.month,now.day)
+    diff=now-today
+    a=round(diff.total_seconds()/60/60/24,6)
+    a100=round(a*100,2)
+    m=str(now.strftime(f'{now} | %mM/%dD/%YY @ %H(24H)/%I %p(12H):%M:%S | {a100} Percent of 24H has passed since {today} as {diff.total_seconds()} seconds passed/{(24*60*60)} total seconds in day={a}*100={a100} | Percent of Day Passed = {a100}%'))
+    return m
+
+
+def ndtp():
+    msg=''
+    while True:
+        try:
+            fields={
+                'distance':{
+                'type':'float',
+                'default':25,
+                },
+                'speed':{
+                'type':'float',
+                'default':70
+                },
+                'total break time':{
+                'type':'string',
+                'default':'10 minutes'
+                }
+            }
+            fd=FormBuilder(data=fields,passThruText=msg)
+            if fd is None:
+                exit(1)
+            
+            mph=fd['speed']
+            distance=fd['distance']
+            try:
+                breaks=pint.Quantity(fd['total break time']).to('seconds').magnitude
+            except Exception as e:
+                breaks=pint.Quantity(fd['total break time']+' minutes').to('seconds').magnitude
+            duration=pint.Quantity(distance/mph,'hour').to('sec').magnitude
+            #12 minutes 
+            buffer=timedelta(minutes=15)
+            original=timedelta(seconds=duration)+timedelta(seconds=breaks)
+            duration=timedelta(seconds=duration+buffer.total_seconds())
+            now=datetime.now()
+            then=now+duration
+            msg=[]
+            msg.append(f'Rate of Travel: {str(mph)}')
+            msg.append(f'Distance To Travel: {distance}')
+            msg.append(f"Now: {now}")
+            msg.append(f'Non-Buffered Duration {original}')
+            msg.append(f'Buffered: {duration} (+{buffer})')
+            msg.append(f"Then: {then}")
+            msg.append(f'Total Break Time: {timedelta(seconds=breaks)}')
+            msg.append(f"From: {nowToPercentTime(now)}")
+            msg.append(f"To: {nowToPercentTime(then)}")
+            msg='\n\n'.join(msg)
+            return msg
+        except Exception as e:
+            print(e)
\ No newline at end of file
